.. pybmix documentation master file, created by
   sphinx-quickstart on Thu May 27 12:18:17 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pybmix's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. toctree::
   :maxdepth: 1
   :caption: Tutorials:

   examples/estimate_univ_density.ipynb
   examples/clustering_univ_data.ipynb
   examples/prior_elicitation.ipynb

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
